@@ -1,4 +1,4 @@
-//    Copyright (C) 2009 Dirk Vanden Boer <dirk.vdb@gmail.com>
+//    Copyright (C) 2010 Dirk Vanden Boer <dirk.vdb@gmail.com>
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -18,16 +18,20 @@
 #define IMAGE_WRITER_H
 
 #include <string>
-#include <inttypes.h>
+#include <cinttypes>
+
+namespace ffmpegthumbnailer
+{
 
 class ImageWriter
 {
 public:
-    ImageWriter() {}
-    virtual ~ImageWriter() {}
+   virtual ~ImageWriter() = default;
 
-	virtual void setText(const std::string& key, const std::string& value) = 0;
-	virtual void writeFrame(uint8_t** rgbData, int width, int height, int quality) = 0;
+   virtual void setText(const std::string& key, const std::string& value) = 0;
+   virtual void writeFrame(uint8_t** rgbData, int width, int height, int quality) = 0;
 };
 
+}
+
 #endif
